/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import attila.core.exception.*;

/**
 * ActionResolvers use information in requests to determine which action of 
 * the controller Attila should invoke.
 * @author Kai Kousa
 * */
public interface ActionResolver {

	/**
	 * Searches the request and the lookup to find an action. If no action is found, an exception gets thrown.
	 * @param request - the current request, wrapped inside <code>AttilaRequest</code>
	 * @param lookup - the request type's(GET, POST) action lookup
	 * */
	public AttilaAction resolveAction(AttilaRequest request, AttilaActionLookup lookup) throws NoSuchActionException;
	
	/**
	 * Returns the <code>ActionInvoker</code> that is able to invoke the actions that this implementation of
	 * ActionResolver understands.
	 * @return <code>ActionInvoker</code>
	 * */
	public ActionInvoker getActionInvoker();
	
}
