/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.util.*;

/**
 * Stores <code>AttilaActions</code> in a <code>Map</code> for faster retrieval.
 * @author Kai Kousa
 * */
public class AttilaActionLookup {

	private Map<String, AttilaAction> nameLookup = new HashMap<String, AttilaAction>();
	private Map<String, AttilaAction> signatureLookup = new HashMap<String, AttilaAction>();
	
	public AttilaActionLookup(){}
	
	public AttilaActionLookup(Map<String, AttilaAction> lookup, Map<String, AttilaAction> signatureLookup){
		this.nameLookup = lookup;
		this.signatureLookup = signatureLookup;
	}
	
	public void setLookups(Map<String, AttilaAction> lookup, Map<String, AttilaAction> signatureLookup){
		this.nameLookup = lookup;
		this.signatureLookup = signatureLookup;
	}
	
	/**
	 * Adds and AttilaAction to this lookup
	 * */
	public void addAction(AttilaAction action){
		nameLookup.put(action.getName(), action);
		signatureLookup.put(action.getActionSignature(), action);
	}
	
	public boolean containsAction(String name){
		return nameLookup.containsKey(name);
	}
	
	public boolean containsActionSignature(String signature){
		return signatureLookup.containsKey(signature);
	}
	
	public Map<String, AttilaAction> getLookupMap(){
		return nameLookup;
	}
	
	public Map<String, AttilaAction> getSignatureLookupMap(){
		return signatureLookup;
	}
	
	/**
	 * @return <code>AttilaAction</code> if found
	 * */
	public AttilaAction getAction(String actionName){
		return nameLookup.get(actionName);
	}
	
	public AttilaAction getActionBySignature(String actionSignature){
		return signatureLookup.get(actionSignature);
	}
	
	/**
	 * Returns the index-action from the lookup.
	 * */
	public AttilaAction getIndex(){
		return nameLookup.get("index");
	}
	
	public boolean hasIndex(){
		return containsAction("index");
	}
	
}
