/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.util.*;

import javax.servlet.http.*;

/**
 * Wraps a <code>HttpServletRequest</code> and let's you add parameters to the request. Used only by 
 * Attila's inner workings.
 * @author Kai Kousa
 * */
public class AttilaRequest extends HttpServletRequestWrapper{

	private Map<String, String> params = new HashMap<String, String>();
	
	public AttilaRequest(HttpServletRequest request) {
		super(request);
	}
	
	@Override
	public String getParameter(String name) {
		if(params.containsKey(name)){
			return params.get(name);
		}else{
			return getRequest().getParameter(name);
		}
	}
	
	public void addParameter(String name, String value){
		params.put(name, value);
	}
	
	public void addParameters(Map<String, String> parameters){
		params.putAll(parameters);
	}

}
