/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.io.IOException;
import java.io.InputStream;
import java.util.*;

import javax.servlet.*;
import javax.servlet.http.*;

import attila.core.util.ServletMappingParser;

/**
 * Sets up the stuff that is needed by Attila The Framework.
 * @author Kai Kousa
 * */
public class AttilaTheListener implements ServletContextListener{
	
	@Override
	public void contextDestroyed(ServletContextEvent contextEvent) {
		
	}

	@Override
	public void contextInitialized(ServletContextEvent contextEvent) {
		ServletContext servletContext = contextEvent.getServletContext();
		readServletMappings(servletContext);
	}

	/**
	 * Creates a Map from the servlet-mappings in the web.xml. These mappings are used in
	 * {@link com.telkku.servlet.BaseServlet}'s redirect-functions
	 * */
	private void readServletMappings(ServletContext servletContext){
		InputStream webXml = servletContext.getResourceAsStream("/WEB-INF/web.xml");
		Map<String, String> servletClassMappings = ServletMappingParser.parseMappings(webXml);
		try {
			webXml.close();
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		servletContext.setAttribute("attila.controllerMappings", servletClassMappings);
	}
	
}
