/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.lang.reflect.InvocationTargetException;

import javax.servlet.http.*;

import attila.core.exception.ActionInvocationException;
import attila.core.util.RequestParamUtil;

/**
 * Simple action invoker that just wraps the parameters if needed and then invokes the action.
 * @author Kai Kousa
 * */
public class BasicActionInvoker implements ActionInvoker{

	@Override
	public void invokeAction(AttilaAction action, AttilaTheServlet servlet, HttpServletRequest request, HttpServletResponse response) throws ActionInvocationException {
		try {
			//Wrap the parameters and invoke the action
			Object[] params = RequestParamUtil.wrapParameters(action.getAction(), request, response);
			action.getAction().invoke(servlet, params);
		
		} catch (IllegalArgumentException e) {
			ActionInvocationException actionEx = new ActionInvocationException("Something went wrong when trying to invoke the action: " + action.getName());
			actionEx.setStackTrace(e.getStackTrace());
			throw actionEx;
		} catch (IllegalAccessException e) {
			ActionInvocationException actionEx = new ActionInvocationException("Something went wrong when trying to invoke the action: " + action.getName());
			actionEx.setStackTrace(e.getStackTrace());
			throw actionEx;
		} catch (InvocationTargetException e) {
			ActionInvocationException actionEx = new ActionInvocationException("Something went wrong when trying to invoke the action: " + action.getName());
			actionEx.setStackTrace(e.getStackTrace());
			throw actionEx;
		}catch(Exception e){
			ActionInvocationException actionEx = new ActionInvocationException("Something went wrong when trying to invoke the action: " + action.getName());
			actionEx.setStackTrace(e.getStackTrace());
			throw actionEx;
		}
	}

}
