/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import attila.helper.RequestHelper;
import attila.core.exception.*;

/**
 * Resolves actions by checking the action-parameter from the request.
 * @author Kai Kousa
 * */
public class BasicActionResolver implements ActionResolver{

	@Override
	public AttilaAction resolveAction(AttilaRequest request, AttilaActionLookup lookup) throws NoSuchActionException{
		String action = RequestHelper.readString("action", request);
		if(action == null){
			if(lookup.hasIndex()){
				return lookup.getIndex();				
			}else{
				throw new NoSuchActionException("Index is not accessible through this HTTP-method (" + request.getMethod() + "). Make sure that this is deliberate by checking your annotations for index. By default, index is accessible through GET-requests.");
			}
		}
		
		if(!lookup.containsAction(action)){
			throw new NoSuchActionException("Couldn't find action: " + action);
		}
		
		return lookup.getAction(action);
	}

	@Override
	public ActionInvoker getActionInvoker() {
		return new BasicActionInvoker();
	}

}
