/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.util.*;

import javax.servlet.http.*;

/**
 * A generic single jsp viewable for ad-hoc view creation.
 * @author Kai Kousa
 * */
public class GenericJSPViewable extends JSPViewable {

	private Map<String, Object> dataMap = new HashMap<String, Object>();
	
	/**
	 * Create a viewable and set it to render a specific JSP-file
	 * @param jspFile - name and path of the JSP file
	 * */
	public GenericJSPViewable(String jspFile) {
		setJspPage(jspFile);
	}
	
	/**
	 * Add data for rendering.
	 * */
	public void addData(String name, Object data){
		dataMap.put(name, data);
	}
	
	@Override
	public void render(HttpServletRequest request, HttpServletResponse response) {
		for(String key : dataMap.keySet()){
			request.setAttribute(key, dataMap.get(key));
		}
		super.render(request, response);
	}
	
}
