/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.*;

import attila.core.exception.*;

/**
 * Simple viewable for rendering single JSP pages.
 * @author Kai Kousa
 * */
public abstract class JSPViewable extends AttilaTheViewable{

	private String jspPage = null;
	
	protected void setJspPage(String jspPage){
		this.jspPage = jspPage;
	}
	
	protected String getJspPage(){
		return jspPage;
	}
	
	@Override
	protected void renderView(HttpServletRequest request, HttpServletResponse response) {
		if(getJspPage() == null){
			throw new ViewableException("No JSP page defined! Use setJspPage()-method to set the JSP page.");
		}
		
		if(!getJspPage().startsWith("/")){
			throw new ViewableException("The path to a JSP-page must begin with a forward slash: '/'. If using AttilaTheTemplate, the paths are relative to the variant-root.");
		}
		
		try {
			request.getSession().getServletContext().getRequestDispatcher(getJspPage()).forward(request, response);
		} catch (ServletException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
