/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import attila.core.exception.*;
import attila.core.util.*;

/**
 * Resolves actions from RESTful urls.
 * @author Kai Kousa
 * */
public class RESTActionResolver implements ActionResolver{

	@Override
	public AttilaAction resolveAction(AttilaRequest request, AttilaActionLookup lookup) throws NoSuchActionException{
		
		RESTUrl restUrl = new RESTUrl(request);
		if(restUrl.isIndex()){
			if(lookup.hasIndex()){
				return lookup.getIndex();				
			}else{
				throw new NoSuchActionException("Index is not accessible through this HTTP-method (" + request.getMethod() + "). Make sure that this is deliberate by checking your annotations for index. By default, index is accessible through GET-requests.");
			}
		}
		
		if(!lookup.containsActionSignature(restUrl.getActionSignature())){
			throw new NoSuchActionException("RESTActionResolver could not find the specified action: " + restUrl.getAction() + "(index=" + restUrl.isIndex() + ", root=" + restUrl.isRoot() + ", httpMethod=" + request.getMethod() + ", url=" + restUrl.getRequestedUrl() + ")");
		}
		
		AttilaAction action = lookup.getActionBySignature(restUrl.getActionSignature());
		
		return action;
	}

	@Override
	public ActionInvoker getActionInvoker() {
		return new RESTActionInvoker();
	}

}
