/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.auth;

import java.lang.annotation.*;

/**
 * Set the authentication level of a controller or an action.
 * @author Kai Kousa
 * */
@Documented
@Retention(RetentionPolicy.RUNTIME)
public @interface AuthLevel {

	/**
	 * <code>AuthenticationLevel</code>-implementation.
	 * */
	@SuppressWarnings("unchecked")
	public Class level();
	
	/**
	 * If an error happens, redirect to this controller
	 * */
	@SuppressWarnings("unchecked")
	public Class[] errorController() default {}; //this is a dirty little hack to get around the "no nulls as default values" restriction of annotations
	
	/**
	 * On error, redirect to this action on the controller defined in errorController-setting. If 
	 * not set, Attila will redirect to index-action of the configured controller.
	 * */
	public String errorControllerAction() default "";
	
}
