/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.auth;

/**
 * Simple factory for creating instances of <code>CookieAuthenticators</code>
 * @author Kai Kousa
 * */
public class CookieAuthenticatorFactory {

	private static Class<? extends CookieAuthenticator> cookieAuthenticatorClass = EmptyCookieAuthenticator.class;
	
	private CookieAuthenticatorFactory(){}
	
	/**
	 * Sets the class that is used to create new instances of <code>CookieAuthenticator</code>
	 * */
	public static void setCookieAuthenticatorClass(Class<? extends CookieAuthenticator> cookieAuthClass){
		cookieAuthenticatorClass = cookieAuthClass;
	}
	
	/**
	 * Creates a new instance of <code>CookieAuthenticator</code>
	 * */
	public static CookieAuthenticator createCookieAuthenticator(){
		
		try {
			return (CookieAuthenticator) cookieAuthenticatorClass.newInstance();
		} catch (InstantiationException e) {
			e.printStackTrace();
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		}
		
		return null;
	}
	
}
