/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.event;

import javax.servlet.http.*;

import attila.core.*;

/**
 * ViewRenderEvent encapsulates all data relevant to the view being rendered.
 * @author Kai Kousa
 * */
public class ViewRenderEvent {

	private AttilaTheViewable view;
	private HttpServletRequest request;
	private HttpServletResponse response;
	
	/**
	 * @param view - the view being rendered
	 * @param request - the current request
	 * @param response - the current response
	 * */
	public ViewRenderEvent(AttilaTheViewable view, HttpServletRequest request, HttpServletResponse response){
		this.view = view;
		this.request = request;
		this.response = response;
	}
	
	/**
	 * Returns the view that is being rendered or has been rendered.
	 * */
	public AttilaTheViewable getView(){
		return view;
	}
	
	/**
	 * Returns the current request
	 * */
	public HttpServletRequest getRequest(){
		return request;
	}
	
	/**
	 * Returns the current response
	 * */
	public HttpServletResponse getResponse(){
		return response;
	}
	
}
