/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import attila.core.auth.*;
import attila.core.exception.AuthLevelMisconfiguredException;

/**
 * @author Kai Kousa
 * */
public class AuthenticationLevelFactory {

	/**
	 * Creates an instance of the configured AuthenticationLevel 
	 * */
	@SuppressWarnings("unchecked")
	public static AuthenticationLevel createAuthenticationLevel(AuthLevel authLevel){
		try {
			Class authenticationLevelClass = authLevel.level();
			AuthenticationLevel authenticationLevel = (AuthenticationLevel) authenticationLevelClass.newInstance();
			
			return authenticationLevel;
		} catch (InstantiationException e) {
			throw new AuthLevelMisconfiguredException("Could not create an instance of " + authLevel.level().getName());
		} catch (IllegalAccessException e) {
			throw new AuthLevelMisconfiguredException("Could no access constructor of " + authLevel.level().getName());
		}catch(ClassCastException e){
			throw new AuthLevelMisconfiguredException("Could not cast " + authLevel.level().getName() + " to attila.core.auth.AuthenticationLevel -interface.");
		}
	}
	
}
