/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import java.lang.reflect.Method;

import javax.servlet.http.*;

import attila.core.*;

/**
 * Useful utility for handling parameters that are handed down onto controllers.
 * @author Kai Kousa
 * */
public class RequestParamUtil {

	/**
	 * Reads the parameters of a method and decides whether to wrap the HttServletRequest to a MultipartRequest or not.
	 * @param m - controller method
	 * @param request - an instance of <code>HttpServletRequest</code>
	 * @param response - an instance of <code>HttpServletResponse</code>
	 * */
	public static Object[] wrapParameters(Method m, HttpServletRequest request, HttpServletResponse response){
		
		Class<?>[] paramTypes = m.getParameterTypes();
		Object[] params = new Object[paramTypes.length];
		
		for(int i = 0; i < paramTypes.length; i++){
			Class<?> paramType = paramTypes[i];
			String paramTypeName = paramType.getName();
			if(paramTypeName.equals(MultipartRequest.class.getName())){
				params[i] = new MultipartRequest(request);
			}else if(paramTypeName.equals(HttpServletRequest.class.getName())){
				params[i] = request;
			}else if(paramTypeName.equals(HttpServletResponse.class.getName())){
				params[i] = response;
			}
		}
		
		return params;
	}
	
}
