/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import java.io.*;
import java.util.*;

import javax.xml.parsers.*;

import org.w3c.dom.*;
import org.xml.sax.SAXException;

/**
 * Helps to create a <code>Map</code> of servlet mappings in web.xml
 * @author Juho Metsovuori
 * @author Kai Kousa
 * */
public class ServletMappingParser {
	
	/**
	 * Parse servlet mappings
	 * @param filename - path to web.xml
	 * */
	public static Map<String, String> parseMappings(String filename){
		try {
			DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
			DocumentBuilder db = dbf.newDocumentBuilder();
			File file = new File(filename);
			if(file.exists()){
				Document webXml = db.parse(file);
				return parseMappings(webXml);
			}
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
		} catch (SAXException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return null;
	}
	
	/**
	 * Parse servlet mappings from an <code>InputStream</code>
	 * @param in - InputStream
	 * */
	public static Map<String, String> parseMappings(InputStream in){
		try {
			DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
			DocumentBuilder db = dbf.newDocumentBuilder();
			Document webXml = db.parse(in);
			return parseMappings(webXml);
		} catch (SAXException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (ParserConfigurationException e) {
			e.printStackTrace();
		}
		
		return null;
	}
	
	private static Map<String, String> parseMappings(Document webXml){
		Map<String, String> servletClassMappings = new HashMap<String, String>();
		
		Map<String, String> servletMappings = new Hashtable<String, String>();
		Element docEle = webXml.getDocumentElement();
		
		NodeList mappingList = docEle.getElementsByTagName("servlet-mapping");
		
		if(mappingList != null && mappingList.getLength() > 0){

			for(int i = 0; i< mappingList.getLength(); i++){
				Element elem = (Element) mappingList.item(i);
				if (elem.getNodeType() == Element.ELEMENT_NODE) {
					String urlPattern = elem.getElementsByTagName("url-pattern").item(0).getTextContent();
					String servletName = elem.getElementsByTagName("servlet-name").item(0).getTextContent();
					servletMappings.put(servletName, urlPattern);
				}
			}

		}

		NodeList servletList = docEle.getElementsByTagName("servlet");
		
		if(servletList != null  && servletList.getLength() > 0){					
			
			for(int i = 0; i< servletList.getLength(); i++){
				Element elem = (Element) servletList.item(i);
				if (elem.getNodeType() == Element.ELEMENT_NODE) {
					String servletClass = elem.getElementsByTagName("servlet-class").item(0).getTextContent();
					String servletName = elem.getElementsByTagName("servlet-name").item(0).getTextContent();
					String urlPattern = servletMappings.get(servletName);
					servletClassMappings.put(servletClass, urlPattern);
				}	
			}

		}
		return servletClassMappings;
	}
}
