/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import java.util.*;

import javax.servlet.*;

/**
 * Utility for getting mapped servlet urls easily.
 * @author Kai Kousa
 * */
public class ServletUrlUtil {

	/**
	 * Creates an url that points to a servlet.
	 * @param servletClassName - class name of the servlet
	 * */
	public static String getServletUrl(String servletClassName, ServletContext servletContext){
		Map<String, String> servletMappings = getServletMappings(servletContext);
		
		String contextPath = servletContext.getContextPath();
		if(!contextPath.endsWith("/")){
			contextPath += "/";
		}
		
		String servletPath = servletMappings.get(servletClassName);
		if(servletPath.startsWith("/")){
			servletPath = servletPath.substring(1);
		}
		
		if(servletPath.endsWith("/*")){
			servletPath = servletPath.substring(0, servletPath.lastIndexOf("/*"));
		}
		
		return contextPath + servletPath;
	}
	
	/**
	 * @return the servlet mappings from the ServletContext
	 * */
	@SuppressWarnings("unchecked")
	public static Map<String, String> getServletMappings(ServletContext servletContext){
		Map<String, String> servletMappings = (Map<String, String>) servletContext.getAttribute("attila.controllerMappings");
		return servletMappings;
	}
	
	/**
	 * @return the context path of the servlet. If it's not the root of the server, adds forward slash(/) 
	 * to the path.
	 * */
	public static String getContextPath(ServletContext servletContext){
		String contextPath = servletContext.getContextPath();
		if(contextPath.length() > 0){
			contextPath += "/";
		}
		return contextPath;
	}
	
}
