/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form;

import attila.form.validators.*;

/**
 * Public interface that represents a field in a form.
 * @author Kai Kousa
 * */
public interface Field {

	/**
	 * Sets the name of the field
	 * @param name - name of the field
	 * */
	public void setName(String name);
	
	/**
	 * @return the name of this field
	 * */
	public String getName();
	
	/**
	 * Sets the value of this field
	 * @param value - value for this field
	 * */
	public void setValue(String value);
	
	/**
	 * @return the value of this field
	 * */
	public String getValue();
	
	/**
	 * Sets the error text of this field
	 * @param errorText - error text of this field
	 * */
	public void setErrorText(String errorText);
	
	/**
	 * @return the error text of this field
	 * */
	public String getErrorText();
	
	/**
	 * Sets the validator for this field
	 * @param rule - an instance of {@link Rule}
	 * */
	public void setValidator(Rule rule);
	
	/**
	 * @return the validator of this field
	 * */
	public Rule getValidator();
	
	/**
	 * Validates the field against the assigned rule
	 * */
	public boolean validate();
	
	/**
	 * Fields can be optional. If a field is optional the validation status doesn't matter.
	 * */
	public void setOptional(boolean optional);
	
	/**
	 * @return true, if this field is optional
	 * */
	public boolean isOptional();
	
	/**
	 * @return true, if the field contains no value(null or empty string)
	 * */
	public boolean isEmpty();
}
