/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form;

/**
 * Public interface that represents a link between two fields
 * @author Kai Kousa
 * */
public interface FieldLink {
	
	/**
	 * Sets the actual fields
	 * @param f1 - first field
	 * @param f2 - second field
	 * */
	public void setLinkedFields(Field f1, Field f2);
	
	/**
	 * Sets the error text of this link. Errors are gathered by the parent form if the link fails.
	 * @param errorText - errorText of this link
	 * */
	public void setErrorText(String errorText);
	
	/**
	 * @return error text of this link
	 * */
	public String getErrorText();
	
	/**
	 * Validates this link. It is up to the implementing class to decide how the validity of the 
	 * link between the two fields should be resolved.
	 * @return true, if the link is valid, false otherwise
	 * */
	public boolean validate();
	
}
