/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form;

import attila.form.validators.*;

/**
 * An implementation of {@link Field}.
 * @author Kai Kousa
 * */
public class SimpleField implements Field{

	private String name;
	private Rule validator;
	private String errorText;
	private String value;
	private boolean optional = false;
	
	public SimpleField(String name, Rule validator, String errorText){
		this.name = name;
		this.validator = validator;
		this.errorText = errorText;
	}

	public SimpleField(String name, Rule validator, String errorText, boolean optional){
		this.name = name;
		this.validator = validator;
		this.errorText = errorText;
		this.optional = optional;
	}
	
	public void setName(String name){
		this.name = name;
	}
	
	public String getName(){
		return name;
	}
	
	public void setValue(String value){
		this.value = value;
	}
	
	public String getValue(){
		return value;
	}
	
	public void setErrorText(String errorText){
		this.errorText = errorText;
	}
	
	public String getErrorText(){
		return errorText;
	}
	
	public void setValidator(Rule validator){
		this.validator = validator;
	}
	
	public Rule getValidator(){
		return validator;
	}
	
	public boolean validate(){
		return validator.validate(value);
	}

	@Override
	public boolean isOptional() {
		return optional;
	}

	@Override
	public void setOptional(boolean optional) {
		this.optional = optional;
	}
	
	@Override
	public boolean isEmpty() {
		if(value == null){
			return true;			
		}
		
		//Remove whitespace and check if the string still contains anything
		String noWhitespaceString = value.trim();
		if(noWhitespaceString.isEmpty()){
			return true;			
		}
		
		return false;
	}
	
}
