/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form.validators;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Base-class for rules that use regular expressions in their validation.
 * @author Kai Kousa
 * */
public class RegExpRule extends Rule {

	private String pattern;
	
	/**
	 * Default constructor
	 * */
	public RegExpRule(){}
	
	/**
	 * Creates an instance of <code>RegExpRule</code>
	 * */
	public RegExpRule(String pattern){
		this.pattern = pattern;
	}
	
	@Override
	public boolean validateString(String s) {
		Pattern pattern = Pattern.compile(getPattern());
		Matcher matcher = pattern.matcher(s);
		return matcher.matches();
	}

	/**
	 * @return a valid regular expression pattern
	 * */
	public String getPattern(){
		return pattern;
	}
	
	public void setPattern(String pattern){
		this.pattern = pattern;
	}
	
}
