/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form.validators;

import java.util.*;

/**
 * Common interface for validation rules.
 * @author Kai Kousa
 * */
public abstract class Rule {
	
	private List<Rule> rules = new ArrayList<Rule>();
	
	/**
	 * Chain rules together.
	 * */
	public Rule add(Rule r){
		rules.add(r);
		return this;
	}
	
	/**
	 * @return <code>true</code> if the string sequence is legal
	 * */
	public final boolean validate(String s){
		boolean result = validateString(s);
		
		if(result){
			for(Rule rule : rules){
				if(!rule.validate(s)){
					result = false;
					break;
				}
			}			
		}
		
		return result;
	}
	
	protected abstract boolean validateString(String s);
	
}
