/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form.validators;

import java.util.*;

/**
 * Contains rules for validating strings. 
 * Accepts:
 * <ul>
 * 	<li>english alphabets</li>
 * 	<li>scandics</li>
 * 	<li>numbers</li>
 * 	<li>empty spaces</li>
 * </ul>
 * If you need to read some other characters from requests, you should write a new <code>Rule</code> 
 * and use that instead. <br />This rule is reserved for basic text only.
 * @author Kai Kousa
 * */
public class ScandicTextRule extends CharByCharRule {

	private List<Character> scandics;
	
	public ScandicTextRule(){
		scandics = new ArrayList<Character>();
		scandics.add('ä');
		scandics.add('Ä');
		scandics.add('ö');
		scandics.add('Ö');
		scandics.add('å');
		scandics.add('Å');
	}	
	
	@Override
	public boolean validate(char c) {
		return (isEnglishCharacter(c) || isScandic(c) || c == ' ');
	}

	protected boolean isEnglishCharacter(char c){
		if ( c>='a' && c<='z' || c>='A' && c<='Z' || c>='0' && c<='9' )
			return true;
		else
			return false;
	}
	
	protected boolean isScandic(char c){
		if(scandics.contains(c)){
			return true;
		}else{
			return false;
		}
	}
	
}
