/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.helper;

import javax.servlet.http.*;
import attila.form.validators.*;

public class CookieHelper {

	/**
	 * Simple function for searching cookies. Is O(n) function but because we don't use
	 * thousands of cookies per user, it is faster than thought.
	 * @param name - name of the cookie
	 * @param request
	 * @return the requested cookie, or <b>null</b> if not found
	 * */
	public static Cookie getCookie(String name, HttpServletRequest request){
		Cookie[] cookies = request.getCookies();
		if(cookies != null){
			for(Cookie cookie : cookies){
				if(cookie.getName().equals(name)){
					return cookie;
				}
			}			
		}
		return null;		
	}
	
	/**
	 * Reads and returns a String from the given Cookie.
	 * */
	public static String readStringValue(Cookie c){
		return readStringValue(c, new ScandicTextRule());
	}
	
	/**
	 * Reads a String value from the given cookie and validates it against the given rule.
	 * @param c - a Cookie
	 * @param rule - the rule against which the value is validated
	 * */
	public static String readStringValue(Cookie c, Rule rule){
		String value = c.getValue();		
		if(rule.validate(value)){
			return value;
		}else{
			return null;
		}
	}
	
	/**
	 * @return integer value from the cookie
	 * */
	public static int readIntValue(Cookie c){
		String value = c.getValue();
		Rule rule = new IntRule();
		if(rule.validate(value)){
			return Integer.parseInt(value);
		}else{
			return 0;
		}
	}
	
	/**
	 * @return float value from the cookie
	 * */
	public static float readFloatValue(Cookie c){
		String value = c.getValue();
		Rule rule = new FloatRule();
		if(rule.validate(value)){
			return Float.parseFloat(value);
		}else{
			return 0;
		}
	}
	
}
