/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.helper;

import java.util.ArrayList;
import java.util.List;

/**
 * Some helper functions for working with XML.
 * @author Kai Kousa
 * */
public class XMLHelper {

	private static List<Character> illegalChars = new ArrayList<Character>();
	static{
		illegalChars.add('&');
		illegalChars.add('<');
		illegalChars.add('>');
	}
	
	/**
	 * Wraps illegal characters(in XML) to CData.
	 * Example: 
	 * String: Bonnie & Clyde should result in String:
	 * Bonnie &lt;![CDATA[&]]&gt; Clyde
	 * */
	public static String wrapToCData(String s){
		if(s != null){			
			StringBuilder builder = new StringBuilder();
			char[] chars = s.toCharArray();
			for(char c : chars){
				if(illegalChars.contains(c)){
					builder.append("<![CDATA[" + c + "]]>");
				}else{
					builder.append(c);
				}
			}
			return builder.toString();
		}else{
			return null;
		}
	}
	
}
