/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.functions;

import java.util.*;
import java.sql.*;

import attila.helper.*;

/**
 * Helpful functions for formatting dates in jsp-pages.
 * @author Kai Kousa
 * */
@Deprecated
public class DateFormatFunction {

	
	/**
	 * Very crude implementation of a formatting function.<br/>
	 * The following strings in the pattern will be replaced with their corresponding values.
	 * <ul>
	 * 	<li>year : YYYY</li>
	 * 	<li>month : MM</li>
	 * 	<li>day : DD</li>
	 * 	<li>hour : hh</li>
	 * 	<li>minute : mm</li>
	 * 	<li>second : ss</li>
	 * 	<li>short month name : SM</li>
	 * 	<li>long month name : LM</li>
	 * 	<li>short weekday name : SW</li>
	 * 	<li>long weekday name : LW</li>
	 * </ul>
	 * @param pattern - see the list above
	 * @param dateObject - an instance of {@link java.util.Calendar} or {@link java.sql.Timestamp}
	 * */
	public static String format(String pattern, Object dateObject){
		if(dateObject != null && pattern != null){
			Calendar date = new GregorianCalendar();
			
			if(dateObject instanceof Calendar){
				date = (Calendar) dateObject;
			}else if(dateObject instanceof Timestamp){
				date = new GregorianCalendar();
				date.setTime((Timestamp) dateObject);
			}else{
				return "";
			}
			
			return format(pattern, date, 0, "en");
		}else{
			return "";			
		}		
	}
	
	public static String format(String pattern, Object dateObject, Integer timezone){
		if(dateObject != null && pattern != null){
			Calendar date = new GregorianCalendar();
			
			if(dateObject instanceof Calendar){
				date = (Calendar) dateObject;
			}else if(dateObject instanceof Timestamp){
				date = new GregorianCalendar();
				date.setTime((Timestamp) dateObject);
			}else{
				return "";
			}
			return format(pattern, date, timezone, "en");
		}else{
			return "";			
		}	
	}
	
	public static String format(String pattern, Object dateObject, String language){
		if(dateObject != null && pattern != null){
			Calendar date = new GregorianCalendar();
			
			if(dateObject instanceof Calendar){
				date = (Calendar) dateObject;
			}else if(dateObject instanceof Timestamp){
				date = new GregorianCalendar();
				date.setTime((Timestamp) dateObject);
			}else{
				return "";
			}
			return format(pattern, date, 0, language);
		}else{
			return "";			
		}
	}
	
	private static String format(String pattern, Calendar date, Integer timezone, String language){
		date.add(Calendar.HOUR_OF_DAY, timezone);
		
		String result = pattern.replace("YYYY", String.valueOf(date.get(Calendar.YEAR)));
		result = result.replace("MM", String.valueOf(addPreZero(date.get(Calendar.MONTH) + 1)));
		result = result.replace("DD", String.valueOf(addPreZero(date.get(Calendar.DAY_OF_MONTH))));
		result = result.replace("hh", String.valueOf(addPreZero(date.get(Calendar.HOUR_OF_DAY))));
		result = result.replace("mm", String.valueOf(addPreZero(date.get(Calendar.MINUTE))));
		result = result.replace("ss", String.valueOf(addPreZero(date.get(Calendar.SECOND))));
		result = result.replace("SW", DateHelper.getShortWeekday(date.get(Calendar.DAY_OF_WEEK), new Locale(language)));
		result = result.replace("LW", DateHelper.getLongWeekday(date.get(Calendar.DAY_OF_WEEK), new Locale(language)));
		
		return result;
	}
	
	private static String addPreZero(int num){
		if(num < 10)
			return "0" + num;
		else
			return "" + num;
	}
	
}
