/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.tags.form;

import java.io.IOException;
import java.util.*;

import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;

import attila.form.*;

/**
 * Parent tag for repopulating forms.
 * @author Kai Kousa
 * */
public class FormTag extends HtmlElementBaseTag{

	private Form formModel = null;
	private Map<String, String> attributes = new HashMap<String, String>();
	
	public Form getFormModel(){
		return formModel;
	}
	
	public void setModel(Object model){
		formModel = (Form)model;
	}
	
	public void setMethod(String method){
		attributes.put("method", method);
	}
	
	public void setAction(String action){
		attributes.put("action", action);
	}
	
	public void setAccept(String accept){
		attributes.put("accept", accept);
	}
	
	public void setAcceptCharset(String acceptCharset){
		attributes.put("accept-charset", acceptCharset);
	}
	
	public void setName(String name){
		attributes.put("name", name);
	}
	
	public void setTarget(String target){
		attributes.put("target", target);
	}
	
	@Override
	public int doStartTag() throws JspException {
		try {
			pageContext.getOut().write("<form " + getAttributes() + " " + getAttributes(attributes) + ">");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return Tag.EVAL_BODY_INCLUDE;
	}
	
	@Override
	public int doEndTag() throws JspException {
		try {
			pageContext.getOut().write("</form>");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return EVAL_PAGE;
	}
	
	
}
