/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.tags.form;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;

import attila.form.*;

/**
 * JSP-tag implementation of input-tag. Able to repopulate
 * itself with previous values.
 * @author Kai Kousa
 * */
public class InputTag extends HtmlElementBaseTag {

	private Map<String, String> attributes = new HashMap<String, String>();
	private String value = null;
	private String name = null;
	private String type = null;
	
	public void setName(String name){
		this.name = name;
	}
	
	public void setType(String type){
		attributes.put("type", type);
		this.type = type;
	}
	
	public void setValue(String value){
		this.value = value;
	}
	
	public void setAccept(String accept){
		attributes.put("accept", accept);
	}
	
	public void setAlt(String alt){
		attributes.put("alt", alt);
	}
	
	public void setChecked(String checked){
		attributes.put("checked", checked);
	}
	
	public void setDisabled(String disabled){
		attributes.put("disabled", disabled);
	}
	
	public void setMaxlength(String maxlength){
		attributes.put("maxlength", maxlength);
	}
	
	public void setReadonly(String readonly){
		attributes.put("readonly", readonly);
	}
	
	public void setSize(String size){
		attributes.put("size", size);
	}
	
	public void setSrc(String src){
		attributes.put("src", src);
	}
	
	@Override
	public int doStartTag() throws JspException {
		try {
			if(type.equals("checkbox")){
				pageContext.getOut().write("<input name=\"" + name + "\" value=\"" + value + "\" " + getCheckedCheckbox() + " " + getAttributes() + " " + getAttributes(attributes) + "/>");
			}else if(type.equals("radio")){
				pageContext.getOut().write("<input name=\"" + name + "\" value=\"" + value + "\" " + getCheckedRadio() + " " + getAttributes() + " " + getAttributes(attributes) + "/>");
			}else{
				pageContext.getOut().write("<input " + getAttributes() + " " + getAttributes(attributes) + " name=\"" + name + "\" value=\"" + getInputValue() + "\" />");				
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		return Tag.SKIP_BODY;
	}
	
	/**
	 * Get value for a field.
	 * */
	private String getInputValue(){
		Form form = getForm();
		
		Field inputField = form.getField(name);			
		if(inputField != null && !inputField.isEmpty()){
			return inputField.getValue();
		}else{
			if(value != null){
				return value;
			}
		}
		
		return "";
	}
	
	/**
	 * Get 'checked' attribute for a radiobutton
	 * */
	private String getCheckedRadio(){
		Form form = getForm();
		Field inputField = form.getField(name);
		if(!inputField.isEmpty() && inputField.getValue().equals(value)){
			return "checked=\"checked\"";
		}else if(!inputField.isEmpty() && !inputField.getValue().equals(value)){//if another value is selected, unselect this one by removing the attribute
			attributes.remove("checked");
		}		
		return "";
	}
	
	/**
	 * Get the 'checked' value for a checkbox.
	 * */
	private String getCheckedCheckbox(){
		Form form = getForm();
		Field inputField = form.getField(name);
		if(!inputField.isEmpty()){
			attributes.remove("checked");//remove the attribute so that it doesn't get rendered twice(if the user already provided the value as the default)
			
			return "checked=\"checked\"";
		}
		
		return "";
	}
	
	/**
	 * Get the form model
	 * */
	private Form getForm(){
		FormTag formTag = (FormTag)findAncestorWithClass(this, FormTag.class);
		Form form = formTag.getFormModel();
		
		return form;
	}
	
}
