/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.tags.form;

import java.io.IOException;
import java.io.StringWriter;
import java.util.*;

import javax.servlet.jsp.JspException;

public class OptionTag extends HtmlElementBaseTag {

	private Map<String, String> attributes;
	private String body = "";
	
	public OptionTag(){
		attributes = new HashMap<String, String>();
	}
	
	public void setDisabled(String disabled){
		attributes.put("disabled", disabled);
	}
	
	public void setLabel(String label){
		attributes.put("label", label);
	}
	
	public void setSelected(String selected){
		attributes.put("selected", selected);
	}
	
	public void setValue(String value){
		attributes.put("value", value);
	}
	
	public String getOptionValue(){
		return attributes.get("value");
	}
	
	public boolean isSelected(){
		return attributes.containsKey("selected");
	}
	
	public void removeSelected(){
		attributes.remove("selected");
	}
	
	public Map<String, String> getHtmlAttributes(){
		return attributes;
	}
	
	public String getBody(){
		return body;
	}
	
	@Override
	public int doAfterBody() throws JspException {
		if(bodyContent != null){
			try {
				StringWriter writer = new StringWriter();
				bodyContent.writeOut(writer);
				body = writer.toString();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return super.doAfterBody();
	}
	
	@Override
	public int doEndTag() throws JspException {
		SelectTag parent = (SelectTag)findAncestorWithClass(this, SelectTag.class);
		parent.addOption(this);
		
		return EVAL_PAGE;
	}
	
}
