/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.tags.form;

import java.io.IOException;
import java.util.*;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;

import attila.form.*;

public class SelectTag extends HtmlElementBaseTag{

	private Map<String, String> attributes = new HashMap<String, String>();
	private List<OptionTag> options = new ArrayList<OptionTag>();
	private String name = null;
	
	public SelectTag(){}
	
	public void setDisabled(String disabled){
		attributes.put("disabled", disabled);
	}
	
	public void setMultiple(String multiple){
		attributes.put("multiple", multiple);
	}
	
	public void setName(String name){
//		attributes.put("name", name);
		this.name = name;
	}
	
	public void setSize(String size){
		attributes.put("size", size);
	}
	
	public void addOption(OptionTag option){
		System.out.println("add option: " + option.getOptionValue());
		options.add(option);
	}
	
	@Override
	public int doStartTag() throws JspException {
		return Tag.EVAL_BODY_INCLUDE;
	}
	
	@Override
	public int doEndTag() throws JspException {
		try {
			pageContext.getOut().write("<select name=\"" + name + "\"" + getAttributes() + " " + getAttributes(attributes) + ">");
			
			select();
			
			for(OptionTag option : options){
				pageContext.getOut().write("<option " + option.getAttributes() + getAttributes(option.getHtmlAttributes()) + ">");
				pageContext.getOut().write(option.getBody());
				pageContext.getOut().write("</option>");
			}
			
			pageContext.getOut().write("</select>");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return Tag.EVAL_PAGE;
	}
	
	private void select(){
		FormTag formTag = (FormTag)findAncestorWithClass(this, FormTag.class);
		Form form = formTag.getFormModel();
		Field field = form.getField(name);
		
		boolean hasDefaultSelectedValue = hasDefaultSelectedValue();
		
		for(OptionTag option : options){
			if(hasDefaultSelectedValue){
				option.removeSelected();
			}
			
			if(!field.isEmpty() && field.getValue().equals(option.getOptionValue())){
				option.setSelected("selected");
			}
		}
	}
	
	private boolean hasDefaultSelectedValue(){
		boolean defaultSelected = false;
		
		for(OptionTag option : options){
			if(option.isSelected()){
				defaultSelected = true;
				break;
			}
		}
		
		return defaultSelected;
	}
	
}
