/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.tags.form;

import java.io.IOException;
import java.util.*;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;

import attila.form.Field;
import attila.form.Form;

/**
 * Implements a textarea-tag.
 * @author Kai Kousa
 * */
public class TextAreaTag extends HtmlElementBaseTag{

	private Map<String, String> attributes = new HashMap<String, String>();
	private String name = null;
	
	public void setCols(String cols){
		attributes.put("cols", cols);
	}
	
	public void setRows(String rows){
		attributes.put("rows", rows);
	}
	
	public void setDisabled(String disabled){
		attributes.put("disabled", disabled);
	}
	
	public void setName(String name){
		this.name = name;
	}
	
	public void setReadonly(String readOnly){
		attributes.put("readonly", readOnly);
	}
	
	@Override
	public int doStartTag() throws JspException {
		try {
			pageContext.getOut().write("<textarea " + getAttributes() + " " + getAttributes(attributes) + " name=\"" + name + "\">");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return EVAL_BODY_BUFFERED;
	}
	
	@Override
	public int doEndTag() throws JspException {
		FormTag formTag = (FormTag)findAncestorWithClass(this, FormTag.class);
		Form form = formTag.getFormModel();
		
		Field inputField = form.getField(name);			
		try {
			if(inputField != null && !inputField.isEmpty()){
				//Overwrite value in the html by the previous value from the field, if it exists
				if(bodyContent != null){
					bodyContent.clearBody();
					bodyContent.write(inputField.getValue());					
				}else{//if no existing body, just write the damn thing
					pageContext.getOut().write(inputField.getValue());
				}
			}
			
			//write the body
			if(bodyContent != null){
				bodyContent.writeOut(bodyContent.getEnclosingWriter());				
			}
			
		} catch (IOException e) {
			e.printStackTrace();
		}
		
		try {
			pageContext.getOut().write("</textarea>");
		} catch (IOException e) {
			e.printStackTrace();
		}
		return Tag.EVAL_PAGE;
	}
	
}
