/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.mock;

import java.io.*;
import java.security.Principal;
import java.util.*;

import javax.servlet.*;
import javax.servlet.http.*;

@SuppressWarnings("unchecked")
public class HttpServletRequestMock implements HttpServletRequest{

	private Map<String, String> parameters = new HashMap<String, String>();
	private Map<String, String> headers = new HashMap<String, String>();
	
	private HttpSession session = null;
	
	private StringBuffer requestUrl = new StringBuffer();
	private String serverName = null;
	private String contextPath = null;
	private int serverPort = 80;
	
	private List<Cookie> cookies = new ArrayList<Cookie>();

	public HttpServletRequestMock() {
		
	}
	
	public void setParameters(Map<String, String> parameters){
		this.parameters = parameters;
	}
	
	public void addParameter(String key, String value){
		parameters.put(key, value);
	}
	
	public void setHeader(String key, String value) {
		headers.put(key, value);
	}

	@Override
	public String getParameter(String arg0) {		
		return parameters.get(arg0);
	}

	public void setSession(HttpSession session){
		this.session = session;
	}

	@Override
	public String getAuthType() {
		return null;
	}

	@Override
	public String getContextPath() {
		return contextPath;
	}
	
	public void setContextPath(String contextPath){
		this.contextPath = contextPath;
	}

	@Override
	public Cookie[] getCookies() {
		Cookie[] cookieArray = new Cookie[cookies.size()];
		for(int i = 0; i < cookies.size(); i++){
			cookieArray[i] = cookies.get(i);
		}
		return cookieArray;
	}
	
	public void addCookie(Cookie c){
		cookies.add(c);
	}

	@Override
	public long getDateHeader(String arg0) {
		return 0;
	}

	@Override
	public String getHeader(String key) {
		return headers.get(key);
	}

	@Override
	public Enumeration getHeaderNames() {
		return new IteratorEnumeration<String>(headers.keySet().iterator());
	}

	@Override
	public Enumeration getHeaders(String arg0) {
		return null;
	}

	@Override
	public int getIntHeader(String arg0) {
		return 0;
	}

	@Override
	public String getMethod() {
		return null;
	}

	@Override
	public String getPathInfo() {
		return null;
	}

	@Override
	public String getPathTranslated() {
		return null;
	}

	@Override
	public String getQueryString() {
		return null;
	}

	@Override
	public String getRemoteUser() {
		return null;
	}

	@Override
	public String getRequestURI() {
		return null;
	}

	@Override
	public StringBuffer getRequestURL() {
		return requestUrl;
	}
	
	public void setRequestURL(StringBuffer requestUrl){
		this.requestUrl = requestUrl;
	}

	@Override
	public String getRequestedSessionId() {
		return null;
	}

	@Override
	public String getServletPath() {
		return null;
	}

	@Override
	public HttpSession getSession() {
		return session;
	}

	@Override
	public HttpSession getSession(boolean arg0) {
		return null;
	}

	@Override
	public Principal getUserPrincipal() {
		return null;
	}

	@Override
	public boolean isRequestedSessionIdFromCookie() {
		return false;
	}

	@Override
	public boolean isRequestedSessionIdFromURL() {
		return false;
	}

	@Override
	public boolean isRequestedSessionIdFromUrl() {
		return false;
	}

	@Override
	public boolean isRequestedSessionIdValid() {
		return false;
	}

	@Override
	public boolean isUserInRole(String arg0) {
		return false;
	}

	@Override
	public Object getAttribute(String arg0) {
		return null;
	}

	@Override
	public Enumeration getAttributeNames() {
		return null;
	}

	@Override
	public String getCharacterEncoding() {
		return null;
	}

	@Override
	public int getContentLength() {
		return 0;
	}

	@Override
	public String getContentType() {
		return null;
	}

	@Override
	public ServletInputStream getInputStream() throws IOException {
		return null;
	}

	@Override
	public String getLocalAddr() {
		return null;
	}

	@Override
	public String getLocalName() {
		return null;
	}

	@Override
	public int getLocalPort() {
		return 0;
	}

	@Override
	public Locale getLocale() {
		return null;
	}

	@Override
	public Enumeration getLocales() {
		return null;
	}

	@Override
	public Map getParameterMap() {
		return null;
	}

	@Override
	public Enumeration<String> getParameterNames() {
		return new IteratorEnumeration<String>(parameters.keySet().iterator());
	}

	@Override
	public String[] getParameterValues(String arg0) {
		return null;
	}

	@Override
	public String getProtocol() {
		return null;
	}

	@Override
	public BufferedReader getReader() throws IOException {
		return null;
	}

	@Override
	public String getRealPath(String arg0) {
		return null;
	}

	@Override
	public String getRemoteAddr() {
		return null;
	}

	@Override
	public String getRemoteHost() {
		return null;
	}

	@Override
	public int getRemotePort() {
		return 0;
	}

	@Override
	public RequestDispatcher getRequestDispatcher(String arg0) {
		return null;
	}

	@Override
	public String getScheme() {
		return null;
	}

	@Override
	public String getServerName() {
		return serverName;
	}

	public void setServerName(String serverName){
		this.serverName = serverName;
	}
	
	@Override
	public int getServerPort() {
		return serverPort;
	}
	
	public void setServerPort(int serverPort){
		this.serverPort = serverPort;
	}

	@Override
	public boolean isSecure() {
		return false;
	}

	@Override
	public void removeAttribute(String arg0) {		
	}

	@Override
	public void setAttribute(String arg0, Object arg1) {		
	}

	@Override
	public void setCharacterEncoding(String arg0) throws UnsupportedEncodingException {
		
	}
	
	/**
	 * Wraps an iterator as an enumeration
	 * @author Eric Andrews
	 */
	private class IteratorEnumeration<T> implements Enumeration<T> {

		private Iterator<T> iterator;
		
		private IteratorEnumeration(Iterator<T> iterator) {
			this.iterator = iterator;
		}
		
		@Override
		public boolean hasMoreElements() {
			return iterator.hasNext();
		}

		@Override
		public T nextElement() {
			return iterator.next();
		}
		
	}
	
}
