/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.template.ant;

import java.io.*;
import java.util.*;

import org.apache.tools.ant.*;

/**
 * Generates a context.xml file by using database information supplied by an Ibatis migration
 * .property file.
 * @author Eric Andrews
 *
 */
public class GenerateContextXmlTask extends Task {

	private String environment;
	private String variant;
	
	/**
	 * Path to the the Ibatis properties file to be used
	 * @param environment
	 */
	public void setEnvironment(String environment) {
		this.environment = environment;
	}

	/**
	 * Path for the output context.xml
	 * @param variant
	 */
	public void setVariant(String variant) {
		this.variant = variant;
	}

	@Override
	public void execute() throws BuildException {	
		try {
			String context = readContextTemplate();
			context = replacePropertyFileValues(context);
			writeContextXmlFile(context);
		} catch (Exception e) {
			throw new BuildException(e);
		}
	}

	private String readContextTemplate() throws FileNotFoundException {
		Scanner scanner = new Scanner(getClass().getResourceAsStream("context.xml"));
		String string = "";
		while (scanner.hasNextLine()) {
			string += scanner.nextLine() + "\n";
		}
		return string;
	}
	
	private String replacePropertyFileValues(String context) throws FileNotFoundException, IOException {
		Properties properties = new Properties();
		properties.load(new FileInputStream(new File(environment)));
		context = context.replace("${USERNAME}", (String) properties.get("username"));
		context = context.replace("${PASSWORD}", (String) properties.get("password"));
		context = context.replace("${DRIVER}", (String) properties.get("driver"));
		context = context.replace("${URL}", (String) properties.get("url"));
		return context;
	}
	
	private void writeContextXmlFile(String context) throws FileNotFoundException {
		PrintWriter out = new PrintWriter(variant);
		out.write(context);
		out.close();
	}
	
}
