/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.template.ant;

import java.io.*;
import java.util.Enumeration;
import java.util.Properties;

import javax.xml.parsers.*;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.apache.tools.ant.*;
import org.w3c.dom.*;
import org.xml.sax.SAXException;

/**
 * Adds all contexts-params from properties file.
 * @author Juho Metsovuori
 * @author Kai Kousa
 * */
public class WebXmlContextParamAddTask extends Task{

	private String propertiesFile = null;
	private String dest = null;
	private String source = null;

	/**
	 * Properties file
	 * */
	public void setPropertiesFile(String propertiesFile) {
		this.propertiesFile = propertiesFile;
	}

	/**
	 * Destination file
	 * */
	public void setDest(String dest){
		this.dest = dest;
	}
	
	/**
	 * Source file
	 * */
	public void setSource(String source){
		this.source = source;
	}
	
	@Override
	public void execute() throws BuildException {
		System.out.println("Properties file: "+propertiesFile);
		if(propertiesFile != null && dest != null && source != null){			
			File webXmlFile = new File(source);
			try {	
				//Read and edit the give web.xml-file
				DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
				DocumentBuilder db = dbf.newDocumentBuilder();
				Document programsDoc = db.parse(webXmlFile);
				
				Properties properties = new Properties();
				properties.load(new FileInputStream(propertiesFile));
				
				Enumeration e = properties.propertyNames();
				//Loop through each property and add it as a context-param
				while(e.hasMoreElements()){
					String key = (String) e.nextElement();
					String value = properties.get(key).toString();

					Element contextParam = programsDoc.createElement("context-param");
					Element paramName = programsDoc.createElement("param-name");
					paramName.setTextContent(key);
					Element paramValue = programsDoc.createElement("param-value");
					paramValue.setTextContent(value);

					contextParam.appendChild(paramName);
					contextParam.appendChild(paramValue);
					
					programsDoc.getFirstChild().appendChild(contextParam);
				}
				
				//Transform and write the xml to a file
				Source source = new DOMSource(programsDoc);
	            StringWriter stringWriter = new StringWriter();
	            Result result = new StreamResult(stringWriter);
	            TransformerFactory factory = TransformerFactory.newInstance();
	            Transformer transformer = factory.newTransformer();
	            transformer.transform(source, result);
	            
				writeWebXmlFile(stringWriter.getBuffer().toString());
				
			} catch (ParserConfigurationException e) {
				e.printStackTrace();
			} catch (SAXException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			} catch (TransformerConfigurationException e) {
				e.printStackTrace();
			} catch (TransformerException e) {
				e.printStackTrace();
			}
			
		}else{
			throw new BuildException("Attributes 'contextParam', 'contextParamValue', 'source' and 'dest' are required");
		}
	}
	
	/**
	 * Write the xml-string to the destination file (overwrites the previous) 
	 * */
	private void writeWebXmlFile(String webXml) throws FileNotFoundException {
		PrintWriter out = new PrintWriter(dest);
		out.write(webXml);
		out.close();
	}
}
