/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.template.ant;

import java.io.*;

import javax.xml.parsers.*;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.apache.tools.ant.*;
import org.w3c.dom.*;
import org.xml.sax.SAXException;

/**
 * Edits the value of a specified context-param -element in web.xml.
 * @author Kai Kousa
 * */
public class WebXmlContextParamEditTask extends Task{

	private String contextParam = null;
	private String contextParamValue = null;
	private String dest = null;
	private String source = null;

	/**
	 * Name of the context parameter in web.xml
	 * */
	public void setContextParam(String contextParam){
		this.contextParam = contextParam;
	}
	
	/**
	 * Value of the context parameter
	 * */
	public void setContextParamValue(String contextParamValue){
		this.contextParamValue = contextParamValue;
	}
	
	/**
	 * Destination file
	 * */
	public void setDest(String dest){
		this.dest = dest;
	}
	
	/**
	 * Source file
	 * */
	public void setSource(String source){
		this.source = source;
	}
	
	@Override
	public void execute() throws BuildException {
		if(contextParam != null && contextParamValue != null && dest != null && source != null){			
			File webXmlFile = new File(source);
			
			try {
				//Read and edit the give web.xml-file
				DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
				DocumentBuilder db = dbf.newDocumentBuilder();
				Document programsDoc = db.parse(webXmlFile);
				
				//Seek the given context-param and set its value
				NodeList contextParamList = programsDoc.getElementsByTagName("context-param");
				for(int i = 0; i < contextParamList.getLength(); i++){
					Element contextParamElement = (Element) contextParamList.item(i);
					if(contextParamElement.getNodeType() == Element.ELEMENT_NODE){
						String paramName = contextParamElement.getElementsByTagName("param-name").item(0).getTextContent();
						
						if(paramName.equals(contextParam)){
							contextParamElement.getElementsByTagName("param-value").item(0).setTextContent(contextParamValue);
						}
					}
				}
				
				//Transform and write the xml to a file
				Source source = new DOMSource(programsDoc);
	            StringWriter stringWriter = new StringWriter();
	            Result result = new StreamResult(stringWriter);
	            TransformerFactory factory = TransformerFactory.newInstance();
	            Transformer transformer = factory.newTransformer();
	            transformer.transform(source, result);
	            
				writeWebXmlFile(stringWriter.getBuffer().toString());
				
				System.out.println("Edited " + source + ". Changed value of " + contextParam + " to " + contextParamValue);
			} catch (ParserConfigurationException e) {
				e.printStackTrace();
			} catch (SAXException e) {
				e.printStackTrace();
			} catch (IOException e) {
				e.printStackTrace();
			} catch (TransformerConfigurationException e) {
				e.printStackTrace();
			} catch (TransformerException e) {
				e.printStackTrace();
			}
			
		}else{
			throw new BuildException("Attributes 'contextParam', 'contextParamValue', 'source' and 'dest' are required");
		}
	}
	
	/**
	 * Write the xml-string to the destination file (overwrites the previous) 
	 * */
	private void writeWebXmlFile(String webXml) throws FileNotFoundException {
		PrintWriter out = new PrintWriter(dest);
		out.write(webXml);
		out.close();
	}
	
}
