/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.util;

import java.io.*;
import java.net.*;
import java.util.*;

import javax.servlet.http.*;

public class POSTRequest {

	private URL url;
	
	private Map<String, String> parameters = new HashMap<String, String>();
	
	public POSTRequest(String urlStr){
		try {
			url = new URL(urlStr);
		} catch (MalformedURLException e) {}
	}
	
	@SuppressWarnings("unchecked")
	public POSTRequest(String urlStr, HttpServletRequest request){
		try {
			url = new URL(urlStr);
			Enumeration paramNames = request.getParameterNames();
			while(paramNames.hasMoreElements()){
				String paramName = (String) paramNames.nextElement();
				String paramValue = request.getParameter(paramName);
				addParameter(paramName, paramValue);
			}
		} catch (MalformedURLException e) {}
	}
	
	public void addParameter(String key, String value){
		parameters.put(key, value);
	}
	
	public String post(){
		String response = "";
	    // URL connection channel.
		try {
			URLConnection urlConn = url.openConnection();
		    // Let the run-time system (RTS) know that we want input.
		    urlConn.setDoInput (true);
		    // Let the RTS know that we want to do output.
		    urlConn.setDoOutput (true);
		    // No caching, we want the real thing.
		    urlConn.setUseCaches (false);
		    // Specify the content type.
		    urlConn.setRequestProperty("Content-Type", "application/x-www-form-urlencoded");
		    // Send POST output.
		    DataOutputStream printout = new DataOutputStream (urlConn.getOutputStream ());
		    
		    StringBuilder postContent = new StringBuilder();
		    for(String key : parameters.keySet()){
		    	String value = parameters.get(key);
		    	postContent.append(URLEncoder.encode(key, "UTF-8")); 
		    	postContent.append("="); 
		    	postContent.append(URLEncoder.encode(value, "UTF-8"));
		    	postContent.append("&");
		    }
		    
		    printout.writeBytes (postContent.toString());
		    printout.flush ();
		    printout.close ();
		    
		    // Get response data.
		    DataInputStream input = new DataInputStream (urlConn.getInputStream ());
		    BufferedReader reader = new BufferedReader(new InputStreamReader(input));
		    String str;
		    while (null != ((str = reader.readLine()))){
		    	response += str + "\n";
		    }
		    input.close ();
		} catch (IOException e) {
			e.printStackTrace();
		}
		return response;
	}
	
}
