/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

import junit.framework.Test;
import junit.framework.TestSuite;

import attila.core.*;
import attila.core.auth.*;
import attila.core.event.*;
import attila.core.util.*;
import attila.form.*;
import attila.form.validators.*;
import attila.helper.*;
import attila.jsp.functions.*;

public class AttilaTests {

	public static Test suite() {
		TestSuite suite = new TestSuite("Tests for attila.*");
		
		//attila.core
		suite.addTestSuite(AttilaActionTests.class);
		suite.addTestSuite(AttilaRequestTests.class);
		suite.addTestSuite(AttilaTheViewableTests.class);
		suite.addTestSuite(BasicActionInvokerTests.class);
		suite.addTestSuite(BasicActionResolverTests.class);
		suite.addTestSuite(RESTActionInvokerTests.class);
		suite.addTestSuite(RESTActionResolverTests.class);
		
		//attila.core.auth
		suite.addTestSuite(CookieAuthenticatorFactoryTests.class);
		suite.addTestSuite(UserSessionTests.class);
		
		//attila.core.event
		suite.addTestSuite(ViewListenerTests.class);
		
		//attila.core.util
		suite.addTestSuite(ActionParserTests.class);
		suite.addTestSuite(RequestParamUtilTests.class);
		suite.addTestSuite(RESTUrlTests.class);
		suite.addTestSuite(ServletMappingParserTests.class);
		suite.addTestSuite(ServletUrlUtilTests.class);

		//attila.form
		suite.addTestSuite(FormTests.class);
		suite.addTestSuite(SimpleFieldTests.class);
		suite.addTestSuite(SimpleFormTests.class);
		
		//attila.form.validators
		suite.addTestSuite(DateIntRuleTests.class);
		suite.addTestSuite(EmailRuleTests.class);
		suite.addTestSuite(FloatRuleTests.class);
		suite.addTestSuite(IntRuleTests.class);
		suite.addTestSuite(LongRuleTests.class);
		suite.addTestSuite(IPAddressRuleTests.class);
		suite.addTestSuite(ISO8601DateRuleTests.class);
		suite.addTestSuite(NotNullRuleTests.class);
		suite.addTestSuite(StringMaxLengthRuleTests.class);
		suite.addTestSuite(StringMinLengthRuleTests.class);
		suite.addTestSuite(StringRuleTests.class);
		suite.addTestSuite(UnderscoreListRuleTests.class);
		
		//attila.helper
		suite.addTestSuite(CookieHelperTests.class);
		suite.addTestSuite(DateHelperTests.class);
		
		//attila.jsp.functions
		suite.addTestSuite(CalendarFormatFunctionTests.class);
		
		return suite;
	}
	
}
