/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import attila.core.util.ActionParser;

import junit.framework.*;

/**
 * Test cases for <code>AttilaAction</code>
 * @author Kai Kousa
 * */
public class AttilaActionTests extends TestCase {

	
	/**
	 * Test the creation of an action signature. HttpServletRequest and HttpServletResponse 
	 * are not counted to the signature.
	 * */
	public void testGetSignature(){
		AttilaAction action = ActionParser.createAction(FooController.class, "index");
		assertEquals("index:0", action.getActionSignature());
	}
	
	public void testGetSignature_parameters(){
		AttilaAction action = ActionParser.createAction(FooController.class, "bar");
		assertEquals("bar:1", action.getActionSignature());
	}
	
	@SuppressWarnings("serial")
	private class FooController extends AttilaTheController{

		@Override
		public void index(HttpServletRequest request, HttpServletResponse response) throws ServletException,IOException {}
		
		@SuppressWarnings("unused")
		@HTTPMethod
		public void bar(int a, HttpServletRequest request, HttpServletResponse response){}
		
	}
	
}
