/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core;

import java.util.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import junit.framework.*;

/**
 * Test cases for AttilaTheViewable.
 * @author Kai Kousa
 * */
public class AttilaTheViewableTests extends TestCase{

	public void testPrepareDataForRendering(){
		Foo foo = new Foo();
		foo.setBar("barbaari");
		
		Map<String, Object> data = foo.prepareDataForRendering();
		assertEquals(foo.getBar(), (String) data.get("bar"));
	}
	
	/**
	 * Test boolean getters in the viewable. As the current practice is to name
	 * getters for boolean values with the prefix 'is' rather than 'get', this test 
	 * will make sure that the viewable handles all conventions equally well.
	 * */
	public void testPrepareDataForRendering_booleanValue(){
		Foo foo = new Foo();
		foo.setBar("barbaari");
		foo.setFooish(true);
		
		Map<String, Object> data = foo.prepareDataForRendering();
		assertEquals(foo.isFooish(), (Boolean) data.get("fooish"));
	}
	
	/**
	 * Dummy class for testing purposes.
	 * */
	private class Foo extends AttilaTheViewable{
		
		private String bar;
		private Boolean fooish;
		
		public Foo(){
			
		}
		
		public void setBar(String bar){
			this.bar = bar;
		}
		
		public void setFooish(Boolean fooish){
			this.fooish = fooish;
		}
		
		public Boolean isFooish(){
			return fooish;
		}
		
		public String getBar(){
			return bar;
		}

		@Override
		public void renderView(HttpServletRequest request, HttpServletResponse response) {
			// no need to implement as this test class doesn't test rendering
		}
		
	}
	
}
