/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.auth;

import junit.framework.*;

import attila.core.auth.AttilaTheUser;
import attila.core.auth.UserSession;
import attila.mock.*;

/**
 * Test cases for <code>UserSession</code>
 * @author Kai Kousa
 * */
public class UserSessionTests extends TestCase{

	public void testIsAuthenticated_fail(){
		
		HttpServletRequestMock request = new HttpServletRequestMock();
		HttpServletResponseMock response = new HttpServletResponseMock();
		HttpSessionMock session = new HttpSessionMock();
		request.setSession(session);
		
		User user = new User();
		
		UserSession.setUserData(request, user);
		
		UserSession<User> userSession = new UserSession<User>(request, response);
		
		assertFalse(userSession.isAuthenticated());
	}
	
	public void testIsAuthenticated_success(){
		HttpServletRequestMock request = new HttpServletRequestMock();
		HttpServletResponseMock response = new HttpServletResponseMock();
		HttpSessionMock session = new HttpSessionMock();
		request.setSession(session);
		
		User user = new User();
		user.setAuthenticated(true);
		
		UserSession.setUserData(request, user);
		
		UserSession<User> userSession = new UserSession<User>(request, response);
		
		assertTrue(userSession.isAuthenticated());
	}
	
	private class User implements AttilaTheUser{

		private boolean authenticated = false;
		
		@Override
		public boolean isAuthenticated() {
			return authenticated;
		}

		@Override
		public void setAuthenticated(boolean authenticated) {
			this.authenticated = authenticated;
		}

		@Override
		public boolean isAuthenticatedByPassword() {
			// TODO Auto-generated method stub
			return false;
		}

		@Override
		public void setAuthenticatedByPassword(boolean authenticated) {
			// TODO Auto-generated method stub
			
		}
		
	}
	
}
