/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.event;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import junit.framework.*;

import attila.core.*;
import attila.mock.*;

/**
 * Test cases for <code>ViewListener</code>
 * @author Kai Kousa
 * */
public class ViewListenerTests extends TestCase {
	
	private HttpServletRequestMock mockRequest = new HttpServletRequestMock();
	private HttpServletResponseMock mockResponse = new HttpServletResponseMock();

	public void testPreRenderEvent(){		
		FooViewListener listener = new FooViewListener();
		
		FooView view = new FooView();
		view.addViewListener(listener);
		
		view.render(mockRequest, mockResponse);
		
		assertTrue(listener.isPreRenderCalled());
	}
	
	public void testPostRenderEvent(){		
		FooViewListener listener = new FooViewListener();
		
		FooView view = new FooView();
		view.addViewListener(listener);
		
		view.render(mockRequest, mockResponse);
		
		assertTrue(listener.isPostRenderCalled());
	}
	
	private class FooViewListener implements ViewListener{

		private boolean postRenderCalled = false;
		private boolean preRenderCalled = false;
		
		@Override
		public void postRender(ViewRenderEvent event) {
			postRenderCalled = true;
		}

		@Override
		public void preRender(ViewRenderEvent event) {
			preRenderCalled = true;
		}
		
		public boolean isPreRenderCalled(){
			return preRenderCalled;
		}
		
		public boolean isPostRenderCalled(){
			return postRenderCalled;
		}
		
	}
	
	public class FooView extends AttilaTheViewable{
		
		private int bar = 26;
		
		public Integer getBar(){
			return bar;
		}
		
		@Override
		protected void renderView(HttpServletRequest request, HttpServletResponse response) {}
	}
	
}
