/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import attila.mock.HttpServletRequestMock;
import junit.framework.*;

/**
 * Test cases for <code>RESTUrl</code>-class.
 * @author Kai Kousa
 * */
public class RESTUrlTests extends TestCase{

	private String urlWithContextControllerActionAndParameter = "http://example.com/testversion/users/user/24";
	private String appContext = "http://example.com/testversion";
	
	public void testParseAction(){
		RESTUrl restUrl = new RESTUrl(urlWithContextControllerActionAndParameter, appContext);
		
		assertEquals("user", restUrl.getAction());
	}
	
	public void testParseAction_oneParameter(){
		RESTUrl restUrl = new RESTUrl(urlWithContextControllerActionAndParameter, appContext);
		
		assertEquals("24", restUrl.getParameterValues().get(0));
	}
	
	public void testParse_index(){
		String url = "http://example.com/testversion/users";
		RESTUrl restUrl = new RESTUrl(url, appContext);
		
		assertEquals("users", restUrl.getController());
		assertTrue(restUrl.isIndex());
	}
	
	public void testParse_rootAndIndex(){
		String url = "http://example.com/testversion";
		RESTUrl restUrl = new RESTUrl(url, appContext);
		
		assertTrue(restUrl.isRoot());
		assertTrue(restUrl.isIndex());
	}
	
	public void testParse_portInUrl(){
		HttpServletRequestMock mockRequest = new HttpServletRequestMock();
		mockRequest.setRequestURL(new StringBuffer("http://example.com:8080/testversion/users/add"));
		mockRequest.setServerName("example.com");
		mockRequest.setContextPath("/testversion/");
		mockRequest.setServerPort(8080);
		
		RESTUrl restUrl = new RESTUrl(mockRequest);
		
		assertEquals("add", restUrl.getAction());
	}
	
//	public void testLongUrl(){
//		String url = "http://localhost/EventStream/api/v1/user/create/hei/he1";
//		String servletMapping = "/api/v1/user/*";
//		HttpServletRequestMock mockRequest = new HttpServletRequestMock();
//		mockRequest.setRequestURL(new StringBuffer(url));
//		mockRequest.setServerName("localhost");
//		mockRequest.setContextPath("/EventStream/");
//		mockRequest.setServerPort(80);
//		
//		RESTUrl restUrl = new RESTUrl(mockRequest, servletMapping);
//		
//		assertEquals("create", restUrl.getAction());
//	}
}
