/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.core.util;

import java.util.*;

import junit.framework.*;

import attila.mock.*;

/**
 * Test cases for <code>ServletUrlUtil</code>.
 * @author Kai Kousa
 * */
public class ServletUrlUtilTests extends TestCase{

	private Map<String, String> servletMappings = new HashMap<String, String>();
	
	@Override
	protected void setUp() throws Exception {
		servletMappings.put("com.example.UserController", "/users");
		servletMappings.put("com.example.SessionController", "/session/*");
	}
	
	public void testGetServletUrl(){
		
		ServletContextMock mockContext = new ServletContextMock();
		mockContext.setAttribute("attila.controllerMappings", servletMappings);
		mockContext.setContextPath("");
		
		String servletUrl = ServletUrlUtil.getServletUrl("com.example.UserController", mockContext);
		
		assertEquals("/users", servletUrl);
	}
	
	public void testGetServletUrl_wildcardMapping(){
		ServletContextMock mockContext = new ServletContextMock();
		mockContext.setAttribute("attila.controllerMappings", servletMappings);
		mockContext.setContextPath("");
		
		String servletUrl = ServletUrlUtil.getServletUrl("com.example.SessionController", mockContext);
		
		assertEquals("/session", servletUrl);
	}
	
}
