/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form;

import junit.framework.*;

import attila.form.validators.*;
import attila.mock.*;

/**
 * Test cases for SimpleForm specific form-tests(most form tests are in FormTests-class). 
 * Tests primarily the reflection based magic of SimpleForm.
 * @author Kai Kousa
 * */
public class SimpleFormTests extends TestCase{
	private HttpServletRequestMock request = new HttpServletRequestMock();
	
	@Override
	protected void setUp() throws Exception {
		super.setUp();
		request.addParameter("username", "kai");
		request.addParameter("password", "password");		
	}

	/**
	 * Test that the instances of <code>Field</code> have been automatically added.
	 * */
	public void testGetFields(){	
		Form form = new TestForm();
		
		form.validate(request);
		
		assertTrue(form.getFields().size() == 2);
	}
	
	/**
	 * Test that the automatically added field references the original field.
	 * */
	public void testGetUsername(){
		TestForm form = new TestForm();
		
		form.validate(request);
		
		assertEquals("kai", form.getUsername());
	}
	
	public void testGetPassword(){
		TestForm form = new TestForm();
		
		form.validate(request);
		
		assertEquals("password", form.getPassword());
	}
	
	/**
	 * Test class for testing automatically added fields.
	 * */
	private class TestForm extends SimpleForm{
		private Rule all = new Rule(){
			public boolean validateString(String s){
				return true;
			}
		};
		
		protected Field username = new SimpleField("username", all, "");
		protected Field password = new SimpleField("password", all, "");
		
		public String getUsername(){
			return username.getValue();
		}
		
		public String getPassword(){
			return password.getValue();
		}
		
	}
	
}
