/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.form.validators;

import junit.framework.*;

/**
 * Test cases for EmailRule
 * @author Kai Kousa
 * */
public class EmailRuleTests extends TestCase{

	public void testValidate(){
		String email = "foo@bar.com";
		
		Rule r = new EmailRule();
		
		assertTrue(r.validate(email));
	}
	
	public void testValidate_britishDomain(){
		String email = "foo@bar.co.uk";
		
		Rule r = new EmailRule();
		
		assertTrue(r.validate(email));
	}
	
	public void testValidate_failEmptyString(){
		String email = "";
		
		Rule r = new EmailRule();
		
		assertFalse(r.validate(email));
	}
	
	public void testValidate_failScandics(){
		String email = "ärjö@yrhå.com";
		
		Rule r = new EmailRule();
		
		assertFalse(r.validate(email));
	}
	
	public void testValidate_failMissingDomain(){
		String email = "foo@com";
		
		Rule r = new EmailRule();
		
		assertFalse(r.validate(email));
	}
	
	public void testValidate_failMissingUser(){
		String email = "@foo.com";
		
		Rule r = new EmailRule();
		
		assertFalse(r.validate(email)); 
	}
	
	public void testValidate_failSpecialCharacters(){
		String email = "?%&@foo.com";
		
		Rule r = new EmailRule();
		
		assertFalse(r.validate(email));
	}
	
	public void testValidate_dot(){
		String email = "kai.kousa@gmail.com";
		
		Rule r = new EmailRule();
		
		assertTrue(r.validate(email));
	}
	
	public void testValidate_underscore(){
		String email = "_kai_kousa@gmail.com";
		
		Rule r = new EmailRule();
		
		assertTrue(r.validate(email));
	}
	
	public void testValidate_longTopLevelDomain(){
		String email = "kai@kousa.info";
		assertTrue(new EmailRule().validate(email));
	}
	
	public void testValidate_dash(){
		String email = "-kai-@kousa.info";
		assertTrue(new EmailRule().validate(email));
	}
	
}
