/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.helper;

import junit.framework.*;

import javax.servlet.http.*;

import attila.mock.*;

public class CookieHelperTests extends TestCase {

	public void testGetCookie(){
		HttpServletRequestMock request = new HttpServletRequestMock();
		Cookie usernameCookie = new Cookie("username", "kai");
		Cookie sessionIdCookie = new Cookie("sessionId", "1123123123");
		
		request.addCookie(usernameCookie);
		request.addCookie(sessionIdCookie);
		
		Cookie result = CookieHelper.getCookie("username", request);
		assertEquals("kai", result.getValue());
	}
	
	public void testGetCookie_notFound(){
		HttpServletRequestMock request = new HttpServletRequestMock();
		Cookie usernameCookie = new Cookie("username", "kai");
		Cookie sessionIdCookie = new Cookie("sessionId", "1123123123");
		
		request.addCookie(usernameCookie);
		request.addCookie(sessionIdCookie);
		
		Cookie result = CookieHelper.getCookie("noSuchCookie", request);
		assertNull(result);
	}
	
	public void testReadStringValue(){
		Cookie stringCookie = new Cookie("username", "kai");
		
		String result = CookieHelper.readStringValue(stringCookie);
		assertEquals("kai", result);
	}
	
	public void testReadStringValue_validationFail(){
		Cookie illegalCookie = new Cookie("username", "#23%");
		
		String result = CookieHelper.readStringValue(illegalCookie);
		assertNull(result);
	}
	
	public void testReadIntValue(){
		Cookie intCookie = new Cookie("userId", "2010");
		
		int result = CookieHelper.readIntValue(intCookie);
		assertEquals(2010, result);
	}
	
	public void testReadIntValue_validationFail(){
		Cookie illegalIntCookie = new Cookie("userId", "23kj89");
		
		int result = CookieHelper.readIntValue(illegalIntCookie);
		assertEquals(0, result);
	}
	
	public void testReadFloatValue(){
		Cookie floatCookie = new Cookie("float", "20.45");
		
		float result = CookieHelper.readFloatValue(floatCookie);
		assertEquals(20.45f, result);
	}
	
	public void testReadFloatValue_validationFail(){
		Cookie illegalFloatCookie = new Cookie("float", "20.kk45");
		
		float result = CookieHelper.readFloatValue(illegalFloatCookie);
		assertEquals(0.0f, result);
	}
	
}
