/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.helper;

import java.util.*;

import junit.framework.*;

/**
 * Tests for DateHelper.
 * @author Kai Kousa
 * */
public class DateHelperTests extends TestCase{

	public void testGetAdjacent(){
		assertEquals(20080607, DateHelper.getAdjacent(20080606, 1));
	}
	
	public void testGetShortWeekday(){
		Locale.setDefault(new Locale("FI"));
		assertEquals("Su", DateHelper.getShortWeekday(1));
	}
	
	public void testGetShortWeekday_english(){
		Locale locale = new Locale("EN");
		assertEquals("Sun", DateHelper.getShortWeekday(1, locale));
	}
	
	public void testGetLongWeekday(){
		Locale.setDefault(new Locale("FI"));
		assertEquals("Sunnuntai", DateHelper.getLongWeekday(1));
	}
	
	public void testGetLongWeekday_english(){
		Locale locale = new Locale("EN");
		assertEquals("Sunday", DateHelper.getLongWeekday(1, locale));
	}
	
	public void testGetAdjacent_next(){
		int input = 20080715;
		int expected = 20080716;
		assertEquals(expected, DateHelper.getAdjacent(input, 1));
	}
	
	public void testGetAdjacent_previous(){
		int input = 20080715;
		int expected = 20080714;
		assertEquals(expected, DateHelper.getAdjacent(input, -1));
	}
	
	public void testTimestampIntToTimestamp(){
		long input = 200807241200l;
		assertEquals(true, (DateHelper.timestampIntToTimestamp(input) != null));
	}
	
	public void testDaysBetweenCalendars(){
		Calendar cal1 = new GregorianCalendar();
		Calendar cal2 = new GregorianCalendar();
		cal2.add(Calendar.DAY_OF_MONTH, 2);
		
		long daysBetween = DateHelper.daysBetweenCalendars(cal1, cal2);
		assertEquals(2, daysBetween);
	}
	
}
