/*
* Copyright 2009-2011 Telkku.com
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package attila.jsp.functions;

import java.util.*;

import junit.framework.TestCase;

public class CalendarFormatFunctionTests extends TestCase {

	private Calendar calendar;
	private String pattern = "EEEE dd.MM.yyyy HH:mm:ss";
	
	@Override
	protected void setUp() throws Exception {
		Locale.setDefault(Locale.ENGLISH);
		calendar = Calendar.getInstance();
		calendar.set(2010, 5, 17, 13, 33, 37);
	}

	public void testFormat() {
		String actual = CalendarFormatFunction.format(calendar, pattern);
		assertEquals("Thursday 17.06.2010 13:33:37", actual);
	}
	
	public void testFormatWithLocale() {
		String actual = CalendarFormatFunction.formatWithLocale(calendar, pattern, new Locale("fi"));
		assertEquals("torstai 17.06.2010 13:33:37", actual);
	}
	
	public void testFormatWithLocaleId() {
		String actual = CalendarFormatFunction.formatWithLocaleId(calendar, pattern, "fi");
		assertEquals("torstai 17.06.2010 13:33:37", actual);
	}
	
	public void testFormatWithTimeZone() {
		String actual = CalendarFormatFunction.formatWithTimeZone(calendar, pattern,
				TimeZone.getTimeZone("Africa/Maputo"));
		assertEquals("Thursday 17.06.2010 12:33:37", actual);
	}
	
	public void testFormatWithTimeZoneId() {
		String actual = CalendarFormatFunction.formatWithTimeZoneId(calendar, pattern, "Africa/Maputo");
		assertEquals("Thursday 17.06.2010 12:33:37", actual);
	}
	
	public void testFormatWithLocaleAndTimeZone() {
		String actual = CalendarFormatFunction.formatWithLocaleAndTimeZone(calendar, pattern,
				Locale.TRADITIONAL_CHINESE, TimeZone.getTimeZone("Asia/Hong_Kong"));
		assertEquals("星期四 17.06.2010 18:33:37", actual);
	}
	
	public void testFormatWithLocaleAndTimeZoneIds() {
		String actual = CalendarFormatFunction.formatWithLocaleAndTimeZoneIds(calendar, pattern,
				"zh", "Asia/Hong_Kong");
		assertEquals("星期四 17.06.2010 18:33:37", actual);
	}
	
	public void testFormatWithNullCalendar() {
		String actual = CalendarFormatFunction.format(null, pattern);
		assertEquals(null, actual);
	}
}
